@@ -1,6 +1,7 @@
+__all__ = ('OrderPoint',)
+
 from expressmoney.api import *
 
-__all__ = ('OrderAPI',)
 
 SERVICE_NAME = 'loans'
 
@@ -18,7 +19,18 @@ class ProductContract(Contract):
     interests = serializers.DecimalField(max_digits=3, decimal_places=2)
 
 
-class OrdersContract(Contract):
+class OrderCreateContract(Contract):
+    amount_requested = serializers.DecimalField(max_digits=7,
+                                                decimal_places=0,
+                                                min_value=1000,
+                                                max_value=15000,
+                                                )
+    period_requested = serializers.IntegerField(min_value=3, max_value=30)
+    bank_card_id = serializers.IntegerField(min_value=1)
+    promocode_code = serializers.CharField(max_length=16, allow_blank=True)
+
+
+class OrderReadContract(OrderCreateContract):
     NEW = 'NEW'
     LOAN_CREATED = 'LOAN_CREATED'
     CANCELED = "CANCELED"
@@ -34,27 +46,21 @@ class OrdersContract(Contract):
     created = serializers.DateTimeField()
     updated = serializers.DateTimeField()
     user_id = serializers.IntegerField(min_value=1)
-    amount_requested = serializers.DecimalField(max_digits=7,
-                                                decimal_places=0,
-                                                min_value=1000,
-                                                max_value=15000,
-                                                )
     amount_approved = serializers.DecimalField(max_digits=7,
                                                decimal_places=0,
                                                allow_null=True,
                                                )
-    period_requested = serializers.IntegerField(min_value=3, max_value=30)
     period_approved = serializers.IntegerField(allow_null=True)
     product = ProductContract()
     amount_limit = AmountLimitContract()
-    bank_card_id = serializers.IntegerField(min_value=1)
     status = serializers.ChoiceField(choices=STATUS_CHOICES)
-    promocode_code = serializers.CharField(max_length=16, allow_blank=True)
     contract_demo = serializers.CharField(max_length=256, allow_blank=True)
 
 
-class OrderAPI(API):
-    _contract = OrdersContract
-    _service_name = SERVICE_NAME
-    _app = 'orders'
-    _point = 'order'
+loans_orders_order = ID(SERVICE_NAME, 'orders', 'order')
+
+
+class OrderPoint(ListPointMixin, CreatePointMixin, ContractPoint):
+    _point_id = loans_orders_order
+    _read_contract = OrderReadContract
+    _create_contract = OrderCreateContract
