@@ -6,7 +6,7 @@ from expressmoney.api import *
 SERVICE_NAME = 'payments'
 
 
-class BankCardContract(Contract):
+class BankCardCreateContract(Contract):
     M01 = "01"
     M02 = "02"
     M03 = "03"
@@ -61,6 +61,16 @@ class BankCardContract(Contract):
         (Y2030, "2030"),
     )
 
+    bin = serializers.CharField(max_length=6)
+    number = serializers.CharField(max_length=4)
+    expiry_month = serializers.ChoiceField(choices=MONTH_CHOICES)
+    expiry_year = serializers.ChoiceField(choices=YEAR_CHOICES)
+    ip = serializers.IPAddressField(allow_blank=True)
+    cryptogram = serializers.CharField(max_length=1024, allow_blank=True)
+    redirect_url = serializers.URLField(max_length=512, allow_blank=True)
+
+
+class BankCardReadContract(BankCardCreateContract):
     PAYPAL = "PAYPAL"
     CLOUDPAYMENTS = "CLOUDPAYMENTS"
     GATEWAY_CHOICES = (
@@ -70,13 +80,6 @@ class BankCardContract(Contract):
     pagination = PaginationContract()
     id = serializers.IntegerField(min_value=1)
     is_active = serializers.BooleanField(default=True)
-    bin = serializers.CharField(max_length=6)
-    number = serializers.CharField(max_length=4)
-    expiry_month = serializers.ChoiceField(choices=MONTH_CHOICES)
-    expiry_year = serializers.ChoiceField(choices=YEAR_CHOICES)
-    ip = serializers.IPAddressField(allow_blank=True)
-    cryptogram = serializers.CharField(max_length=1024, allow_blank=True)
-    redirect_url = serializers.URLField(max_length=512, allow_blank=True)
     gateway = serializers.ChoiceField(choices=GATEWAY_CHOICES)
 
 
@@ -85,11 +88,12 @@ payments_bank_cards_bank_card = ID(SERVICE_NAME, 'bank_cards', 'bank_card')
 
 class BankCardPoint(ListPointMixin, CreatePointMixin, ContractPoint):
     _point_id = payments_bank_cards_bank_card
-    _read_contract = BankCardContract
+    _create_contract = BankCardCreateContract
+    _read_contract = BankCardReadContract
 
 
 """
 from django.contrib.auth import get_user_model
 User = get_user_model()
 user = User.objects.get(id=1)
-"""
\ No newline at end of file
+"""
