@@ -1,4 +1,4 @@
-__all__ = ('UserProfilePoint', 'UserProfileObjectPoint', 'RussianProfileObjectPoint')
+__all__ = ('UserProfilePoint', 'UserProfileObjectPoint', 'RussianProfilePoint', 'RussianProfileObjectPoint')
 
 from expressmoney.api import *
 
@@ -16,7 +16,13 @@ class UserProfileUpdateContract(Contract):
     last_password = serializers.CharField(max_length=8, allow_blank=True)
 
 
-class RussianProfileReadContract(Contract):
+class ProfileUpdateContract(Contract):
+    first_name = serializers.CharField(max_length=32)
+    last_name = serializers.CharField(max_length=32)
+    middle_name = serializers.CharField(max_length=32)
+
+
+class ProfileCreateContract(ProfileUpdateContract):
     NONE = 'NONE'
     PASSPORT = "PP"
     DRIVING_LICENCE = "DL"
@@ -30,15 +36,7 @@ class RussianProfileReadContract(Contract):
         (INSURANCE, gettext_lazy('SNILS')),
     )
 
-    created = serializers.DateTimeField()
-    updated = serializers.DateTimeField()
-    first_name = serializers.CharField(max_length=32)
-    last_name = serializers.CharField(max_length=32)
-    middle_name = serializers.CharField(max_length=32)
     birth_date = serializers.DateField()
-    # Underwriting
-    is_identified = serializers.BooleanField()
-    is_verified = serializers.BooleanField()
     # Address
     postal_code = serializers.CharField(max_length=16, allow_blank=True)
     state = serializers.CharField(max_length=32, allow_blank=True)
@@ -51,33 +49,67 @@ class RussianProfileReadContract(Contract):
     address = serializers.CharField(max_length=256, allow_blank=True)
     address_optional = serializers.CharField(max_length=64, allow_blank=True)
     po_box = serializers.CharField(max_length=8, allow_blank=True)
-    address_code = serializers.CharField(max_length=64, allow_blank=True)
-    address_coordinates = serializers.CharField(max_length=64, allow_blank=True)
     # Government ID
     government_id_type = serializers.ChoiceField(choices=GOVERNMENT_ID_TYPE_CHOICES)
     government_id_number = serializers.CharField(max_length=16, allow_blank=True)
     government_id_date = serializers.DateField(allow_null=True)
-    # RussianProfile
+
+
+class ProfileReadContract(ProfileCreateContract):
+    created = serializers.DateTimeField()
+    updated = serializers.DateTimeField()
+    # Underwriting
+    is_identified = serializers.BooleanField()
+    is_verified = serializers.BooleanField()
+    # Address
+    address_code = serializers.CharField(max_length=64, allow_blank=True)
+    address_coordinates = serializers.CharField(max_length=64, allow_blank=True)
+
+
+class RussianProfileUpdateContractMixin:
+    # Russian fields
     passport_serial = serializers.CharField(max_length=4)
     passport_number = serializers.CharField(max_length=6)
+
+
+class RussianProfileCreateContractMixin:
+    # Russian fields
     passport_issue_name = serializers.CharField(max_length=256, allow_blank=True)
     passport_code = serializers.CharField(max_length=16)
     passport_date = serializers.DateField()
     income = serializers.IntegerField(allow_null=True)
+
+
+class RussianProfileReadContractMixin:
+    # Russian fields
     income_region = serializers.IntegerField(allow_null=True)
     court_address = serializers.CharField(max_length=256, allow_blank=True)
     fias_region = serializers.CharField(max_length=256, allow_blank=True)
 
 
+class RussianProfileUpdateContract(RussianProfileUpdateContractMixin, ProfileUpdateContract):
+    pass
+
+
+class RussianProfileCreateContract(RussianProfileUpdateContractMixin,
+                                   RussianProfileCreateContractMixin,
+                                   ProfileCreateContract
+                                   ):
+    pass
+
+
+class RussianProfileReadContract(RussianProfileUpdateContractMixin,
+                                 RussianProfileCreateContractMixin,
+                                 RussianProfileReadContractMixin,
+                                 ProfileReadContract,
+                                 ):
+    pass
+
+
 profiles_profiles_russian_profile = ID(SERVICE_NAME, 'profiles', 'russian_profile')
 profiles_profiles_user_profile = ID(SERVICE_NAME, 'profiles', 'user_profile')
 
 
-class RussianProfileObjectPoint(RetrievePointMixin, ContractObjectPoint):
-    _point_id = profiles_profiles_russian_profile
-    _read_contract = RussianProfileReadContract
-
-
 class UserProfilePoint(CreatePointMixin, ContractPoint):
     _point_id = profiles_profiles_user_profile
     _create_contract = UserProfileCreateContract
@@ -88,8 +120,12 @@ class UserProfileObjectPoint(UpdatePointMixin, ContractObjectPoint):
     _update_contract = UserProfileUpdateContract
 
 
-"""
-from django.contrib.auth import get_user_model
-User = get_user_model()
-user = User.objects.get(id=1)
-"""
\ No newline at end of file
+class RussianProfilePoint(CreatePointMixin, ContractPoint):
+    _point_id = profiles_profiles_russian_profile
+    _create_contract = RussianProfileCreateContract
+
+
+class RussianProfileObjectPoint(RetrievePointMixin, UpdatePointMixin, ContractObjectPoint):
+    _point_id = profiles_profiles_russian_profile
+    _read_contract = RussianProfileReadContract
+    _update_contract = RussianProfileUpdateContract
