@@ -1,6 +1,4 @@
-"""
-Utils for Viewflow framework.
-"""
+__all__ = ('fix_flow_signal', )
 
 
 def fix_flow_signal(func):
